@@ -5,8 +5,7 @@
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#    the Free Software Foundation; version 2 of the License.
 #
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -104,7 +103,10 @@ def getserverobject(config):
                 self.server_name = config.get("pygopherd", "servername")
             else:
                 self.server_name = socket.getfqdn(host)
-            self.server_port = port
+            if config.has_option("pygopherd", "advertisedport"):
+                self.server_port = config.getint("pygopherd", "advertisedport")
+            else:
+                self.server_port = port
 
     # Instantiate a server.  Has to be done before the security so we can
     # get a privileged port if necessary.
@@ -188,6 +190,7 @@ def initeverything(conffile):
     pgrp = initpgrp(config)
     initsighandlers(config, pgrp)
     initsecurity(config)
+    os.chdir(config.get("pygopherd", "root"))
 
     logger.log("Running.  Root is '%s'" % config.get("pygopherd", "root"))
     return s
